==> wrapper-spring-boot-starter-7.2.4-sources.jar: cn/stylefeng/roses/kernel/wrapper/starter/GunsWrapperAutoConfiguration.java <==
/*
 * Copyright [2020-2030] [https://www.stylefeng.cn]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Guns采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Guns源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://gitee.com/stylefeng/guns
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/stylefeng/guns
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */
package cn.stylefeng.roses.kernel.wrapper.starter;

import cn.stylefeng.roses.kernel.wrapper.WrapperAop;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * Wrapper的自动配置
 *
 * @author fengshuonan
 * @date 2021/1/19 22:42
 */
@Configuration
public class GunsWrapperAutoConfiguration {

    /**
     * Wrapper的自动配置
     *
     * @author fengshuonan
     * @date 2021/1/19 22:42
     */
    @Bean
    @ConditionalOnMissingBean(WrapperAop.class)
    public WrapperAop wrapperAop() {
        return new WrapperAop();
    }

}

==> wrapper-spring-boot-starter-7.3.3-sources.jar: cn/stylefeng/roses/kernel/wrapper/starter/GunsWrapperAutoConfiguration.java <==
/*
 * Copyright [2020-2030] [https://www.stylefeng.cn]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Guns采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Guns源码头部的版权声明。
 * 3.请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://gitee.com/stylefeng/guns
 * 5.在修改包名，模块名称，项目代码等时，请注明软件出处 https://gitee.com/stylefeng/guns
 * 6.若您的项目无法满足以上几点，可申请商业授权
 */
package cn.stylefeng.roses.kernel.wrapper.starter;

import cn.stylefeng.roses.kernel.wrapper.WrapperAop;
import cn.stylefeng.roses.kernel.wrapper.field.mvc.CustomEnumGenericConverter;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * Wrapper的自动配置
 *
 * @author fengshuonan
 * @date 2021/1/19 22:42
 */
@Configuration
public class GunsWrapperAutoConfiguration {

    /**
     * Wrapper的自动配置
     *
     * @author fengshuonan
     * @date 2021/1/19 22:42
     */
    @Bean
    @ConditionalOnMissingBean(WrapperAop.class)
    public WrapperAop wrapperAop() {
        return new WrapperAop();
    }

    /**
     * 自定义spring mvc的参数转化器，将请求参数转化为枚举
     *
     * @author fengshuonan
     * @date 2022/9/24 18:32
     */
    @Bean
    public CustomEnumGenericConverter customEnumGenericConverter() {
        return new CustomEnumGenericConverter();
    }

}
